==> django_formset-0.8.1-py3-none-any.whl: testapp/forms/opinion.py <==
from django.forms import fields, forms, models, widgets

from formset.widgets import Selectize, DualSelector, SelectizeMultiple

from testapp.models import OpinionModel


class OpinionForm(forms.Form):
    """
    Fields with Single and Multiple Choices
    ---------------------------------------

    This form shows the usage of different choices fields.

    The **Classic Select** uses a Django ``ChoiceField`` using the classic ``<select>`` widget.
    This is the default and shall only be used for fields with a very few choices, say less than 10.

    The **Static Opinion** uses a Django ``ChoiceField`` using the new ``Selectize`` widget with a
    fixed set of choices. It shall be used when the number of choices exceeds 10 but is also well
    suitable for less.

    The **Dynamic Opinion** field shows a ``ModelChoiceField`` using the ``Selectize`` widget
    configured to query from the associated model. While typing into this field, the number of
    choices narrows down to those matching the search string.

    The **Few Opinions** field shows a ``ModelMultipleChoiceField`` using the ``SelectizeMultiple``
    widget configured to query from the associated model. It behaves similar to the ``Selectize``
    widget, but allows to choose one or more choices. It shall be used if the number of selected
    choices does not exceed more than say 10.

    The **Many Opinions** field shows a ``ModelMultipleChoiceField`` using the ``DualSelector``
    widget configured to query from the associated model. It shows two ``<select multiple>``
    elements, the left to show available choices and the right to keep the selected choices.
    It shall be used if the number of selected choices may exceed 10 or more.

    The **Annotation** field is just added as a reference to compare the feedback from the
    ``Selectize`` widget with a standard input field.
    """

    choice = fields.ChoiceField(
        label="Classic Select",
        choices=[
            (None, "Commit yourself"),
            (1, "In favor"),
            (2, "Against"),
            (3, "Don't know"),
        ],
    )

    static_opinion = fields.ChoiceField(
        label="Static Opinion",
        choices=lambda: OpinionModel.objects.filter(tenant=1).values_list('id', 'label')[:99],
        widget=Selectize,
    )

    dynamic_opinion = models.ModelChoiceField(
        label="Dynamic Opinion",
        queryset=OpinionModel.objects.filter(tenant=1),
        widget=Selectize(search_lookup='label__icontains', placeholder="Select opinion dynamically"),
        required=True,
    )

    few_opinions = models.ModelMultipleChoiceField(
        label="Few Opinions",
        queryset=OpinionModel.objects.filter(tenant=1),
        widget=SelectizeMultiple(search_lookup='label__icontains', placeholder="Select any opinion", max_items=15),
    )

    many_opinions = models.ModelMultipleChoiceField(
        label="Many Opinions",
        queryset=OpinionModel.objects.filter(tenant=1),
        widget=DualSelector(search_lookup='label__icontains'),
    )

    annotation = fields.CharField(
        label="Annotation",
        widget=widgets.TextInput(attrs={'placeholder': "Start typing ..."}),
        required=False,
        help_text="I have to say something",
    )


sample_opinion_data = {
    'choice': 2,
    'static_opinion': lambda: OpinionModel.objects.filter(tenant=1)[6],
    'dynamic_opinion': lambda: OpinionModel.objects.filter(tenant=1)[9],
    'annotation': "Lorem ipsum dolor est",
}

==> django_formset-0.8.3-py3-none-any.whl: testapp/forms/opinion.py <==
from django.forms import fields, forms, models, widgets

from formset.widgets import Selectize, DualSelector, SelectizeMultiple

from testapp.models import OpinionModel


class OpinionForm(forms.Form):
    """
    Fields with Single and Multiple Choices
    ---------------------------------------

    This form shows the usage of different choices fields.

    The **Classic Select** uses a Django ``ChoiceField`` using the classic ``<select>`` widget.
    This is the default and shall only be used for fields with a very few choices, say less than 10.

    The **Static Opinion** uses a Django ``ChoiceField`` using the new ``Selectize`` widget with a
    fixed set of choices. It shall be used when the number of choices exceeds 10 but is also well
    suitable for less.

    The **Dynamic Opinion** field shows a ``ModelChoiceField`` using the ``Selectize`` widget
    configured to query from the associated Django Model. While typing into this field, the number
    of choices narrows down to those matching the search query string.

    The **Few Opinions** field shows a ``ModelMultipleChoiceField`` using the ``SelectizeMultiple``
    widget configured to query from the associated model. It behaves similar to the ``Selectize``
    widget, but allows to choose one or more options. It shall be used if the maximum number of
    selectable options does not exceed more than say 10.

    The **Many Opinions** field shows a ``ModelMultipleChoiceField`` using the ``DualSelector``
    widget configured to query from the associated Django Model. It shows two ``<select multiple>``
    elements, the left offering all available options and the right to keep the selected options.
    It shall be used if the number of selected options can exceed any number.

    The **Annotation** field is just added as a reference to compare the feedback from the
    ``Selectize`` widget with a standard input field.
    """

    choice = fields.ChoiceField(
        label="Classic Select",
        choices=[
            (None, "Commit yourself"),
            (1, "In favor"),
            (2, "Against"),
            (3, "Don't know"),
        ],
    )

    static_opinion = fields.ChoiceField(
        label="Static Opinion",
        choices=lambda: OpinionModel.objects.filter(tenant=1).values_list('id', 'label')[:99],
        widget=Selectize,
    )

    dynamic_opinion = models.ModelChoiceField(
        label="Dynamic Opinion",
        queryset=OpinionModel.objects.filter(tenant=1),
        widget=Selectize(search_lookup='label__icontains', placeholder="Select opinion dynamically"),
        required=True,
    )

    few_opinions = models.ModelMultipleChoiceField(
        label="Few Opinions",
        queryset=OpinionModel.objects.filter(tenant=1),
        widget=SelectizeMultiple(search_lookup='label__icontains', placeholder="Select any opinion", max_items=15),
    )

    many_opinions = models.ModelMultipleChoiceField(
        label="Many Opinions",
        queryset=OpinionModel.objects.filter(tenant=1),
        widget=DualSelector(search_lookup='label__icontains'),
    )

    annotation = fields.CharField(
        label="Annotation",
        widget=widgets.TextInput(attrs={'placeholder': "Start typing ..."}),
        required=False,
        help_text="I have to say something",
    )


sample_opinion_data = {
    'choice': 2,
    'static_opinion': lambda: OpinionModel.objects.filter(tenant=1)[6],
    'dynamic_opinion': lambda: OpinionModel.objects.filter(tenant=1)[9],
    'annotation': "Lorem ipsum dolor est",
}
